import "./tasks/Realigner.wdl" as Realigner
import "./tasks/BQSR.wdl" as BQSR
import "./tasks/PoN.wdl" as PoN
  
workflow {{ project_name }} {
  String SENTIEON_INSTALL_DIR
  String SENTIEON_LICENSE
  String panel_id

  File ref_dir
  String fasta
  File cosmic_dir
  String cosmic_vcf
  File dbsnp_dir
  String dbsnp
  File regions

  Array[Array[File]] normal_recaled_bam_bai
  String sentieon_docker
  String cluster_config
  String disk_size
  
  
  call Realigner.Realigner as Realigner {
    input:
    SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
    SENTIEON_LICENSE=SENTIEON_LICENSE,
    fasta=fasta,
    ref_dir=ref_dir,
    deduped_bam=Dedup.deduped_bam,
    deduped_bam_index=Dedup.deduped_bam_index,
    db_mills=db_mills,
    dbmills_dir=dbmills_dir,
    sample=sample_id + '_tumor',
    docker=sentieon_docker,
    disk_size=disk_size,
    cluster_config=cluster_config
  }

  call BQSR.BQSR as BQSR {
    input:
    SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
    SENTIEON_LICENSE=SENTIEON_LICENSE,
    fasta=fasta,
    ref_dir=ref_dir,
    realigned_bam=Realigner.realigner_bam,
    realigned_bam_index=Realigner.realigner_bam_index,
    db_mills=db_mills,
    dbmills_dir=dbmills_dir,
    dbsnp=dbsnp,
    dbsnp_dir=dbsnp_dir,
    sample=sample_id + '_tumor',
    docker=sentieon_docker,
    disk_size=disk_size,
    cluster_config=cluster_config
  }

  call PoN.PoN as PoN {
    input:
    SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
    SENTIEON_LICENSE=SENTIEON_LICENSE,
    fasta=fasta,
    ref_dir=ref_dir,
    regions=regions,
    normal_bam=BQSR.recaled_bam,
    normal_bam_index=BQSR.recaled_bam_index,
    cosmic_vcf=cosmic_vcf,
    cosmic_dir=cosmic_dir,
    dbsnp=dbsnp,
    dbsnp_dir=dbsnp_dir,
    docker=sentieon_docker,
    disk_size=disk_size,
    cluster_config=cluster_config
    }
  }
}